@@ -24,9 +24,9 @@ SPDX-License-Identifier: MIT
 
 from abc import abstractmethod
 from enum import Enum
-from typing import Any, Callable, Dict, List
+from typing import Any, Callable, Dict, Generic, List, TypeVar
 
-from .inspect_base import InspectBase
+from ..scanossbase import ScanossBase
 from .utils.license_utils import LicenseUtil
 
 
@@ -35,19 +35,20 @@ class PolicyStatus(Enum):
     Enumeration representing the status of a policy check.
 
     Attributes:
-        SUCCESS (int): Indicates that the policy check passed successfully (value: 0).
-        FAIL (int): Indicates that the policy check failed (value: 1).
-        ERROR (int): Indicates that an error occurred during the policy check (value: 2).
+        POLICY_SUCCESS (int): Indicates that the policy check passed successfully (value: 0).
+        POLICY_FAIL (int): Indicates that the policy check failed (value: 2).
+        ERROR (int): Indicates that an error occurred during the policy check (value: 1).
     """
-
-    SUCCESS = 0
-    FAIL = 1
-    ERROR = 2
+    POLICY_SUCCESS = 0
+    POLICY_FAIL = 2
+    ERROR = 1
 #
 # End of PolicyStatus Class
 #
 
-class PolicyCheck(InspectBase):
+T = TypeVar('T')
+
+class PolicyCheck(ScanossBase, Generic[T]):
     """
     A base class for implementing various software policy checks.
 
@@ -66,19 +67,17 @@ class PolicyCheck(InspectBase):
             debug: bool = False,
             trace: bool = False,
             quiet: bool = False,
-            filepath: str = None,
             format_type: str = None,
             status: str = None,
-            output: str = None,
             name: str = None,
+            output: str = None,
     ):
-        super().__init__(debug, trace, quiet, filepath, output)
+        super().__init__(debug, trace, quiet)
         self.license_util = LicenseUtil()
-        self.filepath = filepath
         self.name = name
         self.format_type = format_type
         self.status = status
-        self.results = self._load_input_file()
+        self.output = output
 
     @abstractmethod
     def run(self):
@@ -99,41 +98,41 @@ class PolicyCheck(InspectBase):
         pass
 
     @abstractmethod
-    def _json(self, components: list) -> Dict[str, Any]:
+    def _json(self, data: list[T]) -> Dict[str, Any]:
         """
         Format the policy checks results as JSON.
         This method should be implemented by subclasses to create a Markdown representation
         of the policy check results.
 
-        :param components: List of components to be formatted.
+        :param data: List of data to be formatted.
         :return: A dictionary containing two keys:
-                 - 'details': A JSON-formatted string with the full list of components
+                 - 'results': A JSON-formatted string with the full list of components
                  - 'summary': A string summarizing the number of components found
         """
         pass
 
     @abstractmethod
-    def _markdown(self, components: list) -> Dict[str, Any]:
+    def _markdown(self, data: list[T]) -> Dict[str, Any]:
         """
         Generate Markdown output for the policy check results.
 
         This method should be implemented by subclasses to create a Markdown representation
         of the policy check results.
 
-        :param components: List of components to be included in the output.
+        :param data: List of data to be included in the output.
         :return: A dictionary representing the Markdown output.
         """
         pass
 
     @abstractmethod
-    def _jira_markdown(self, components: list) -> Dict[str, Any]:
+    def _jira_markdown(self, data: list[T]) -> Dict[str, Any]:
         """
         Generate Markdown output for the policy check results.
 
         This method should be implemented by subclasses to create a Markdown representation
         of the policy check results.
 
-        :param components: List of components to be included in the output.
+        :param data: List of data to be included in the output.
         :return: A dictionary representing the Markdown output.
         """
         pass
@@ -208,7 +207,6 @@ class PolicyCheck(InspectBase):
             self.print_stderr(f'Format: {self.format_type}')
             self.print_stderr(f'Status: {self.status}')
             self.print_stderr(f'Output: {self.output}')
-            self.print_stderr(f'Input: {self.filepath}')
 
     def _is_valid_format(self) -> bool:
         """
@@ -224,6 +222,39 @@ class PolicyCheck(InspectBase):
             self.print_stderr(f'ERROR: Invalid format "{self.format_type}". Valid formats are: {valid_formats_str}')
             return False
         return True
+
+    def _generate_formatter_report(self, components: list[Dict]):
+        """
+        Generates a formatted report for a given component based on the defined formatter.
+
+        Parameters:
+            components (List[dict]): A list of dictionaries representing the components to be
+            processed and formatted. Each dictionary contains detailed information that adheres
+            to the format requirements for the specified formatter.
+
+        Returns:
+            Tuple[int, dict]: A tuple where the first element represents the policy status code
+            and the second element is a dictionary containing formatted results information,
+            typically with keys 'details' and 'summary'.
+
+        Raises:
+            KeyError: When a required key is missing from the provided component, causing the
+            formatter to fail.
+            ValueError: If an invalid component is passed and renders unable to process.
+        """
+        # Get a formatter for the output results
+        formatter = self._get_formatter()
+        if formatter is None:
+            return PolicyStatus.ERROR.value, {}
+        # Format the results
+        data = formatter(components)
+        ## Save outputs if required
+        self.print_to_file_or_stdout(data['details'], self.output)
+        self.print_to_file_or_stderr(data['summary'], self.status)
+        # Check to see if we have policy violations
+        if len(components) > 0:
+            return PolicyStatus.POLICY_FAIL.value, data
+        return PolicyStatus.POLICY_SUCCESS.value, data
 #
 # End of PolicyCheck Class
 #
\ No newline at end of file
